%VORTEX INDUCED VIBRATIONS

clear all;

U0 = 40;            %Mean wind speed
L = 70;             %Height of tower
t1 = 0.038;         %Bottom shell thickness
t2 = 0.011;         %Mid shell thickness
t3 = 0.008;         %Top shell thickness
T = 15;             %Mean period
C_a =0.6;           %Added mass coeff.
rho_a = 1.226;      %Density air
rho_s = 7850;       %Density steel
upsilon = 1.5*10^-5;%Kinematic viscosity air
D_mean = 4;         %Mean diameter

%Reading damping coeff., eigenvalues and dimensions from spreadsheet
filename = 'damp.xlsx';
damp = xlsread(filename);
filename2 = 'eigen2.xlsx';
eigen = xlsread(filename2);
filename3 = 'dim.xlsx';
H = xlsread(filename3,'A:A');
D = xlsread(filename3,'B:B');

%Cross sectional areas
for i = 1:6
A(i) = pi*((D(i)/2)^2-((D(i)/2)-t1)^2);
end
for i = 7:12 
A(i) = pi*((D(i)/2)^2-((D(i)/2)-t2)^2);
end
for i = 13:19 
A(i) = pi*((D(i)/2)^2-((D(i)/2)-t3)^2);
end
Sa = 0;
Sd = 0;
n = length(A);
for i = 1:length(A)
    Sa = Sa + A(i);
    Sd = Sd + D(i);
end

%Equivalent mass
m = (Sa/length(A))*rho_s;
m_a = C_a*pi*(Sd/length(D))^2*rho_a;
m_e = m+m_a;

%Wind profile
C = (5.73E-2)*sqrt(1+(0.148*U0));
for i = 1:length(H)
Iu(i) = 0.06*(1+(0.043*U0))*(H(i)/10)^(-0.22);
Uz(i) = U0*(1+(C*log(H(i)/10)));
u(i) = Uz(i)*(1-(0.41*Iu(i)*log(T/3600)));
end



alpha = damp(1);
beta = damp(2);
%Damping ratios and stability parameter
for i = 1:length(eigen)
    zeta(i) = 0.5*((alpha/eigen(i))+(beta*eigen(i)^2)); 
    delta(i) = 2*pi*zeta(i);
    K_s(i) = (2*m_e*delta(i))/(rho_a*(Sd/length(D))^2);
end

%Reynolds number
for i = 1:length(D)
    Re(i) = u(i)*D(i)/upsilon;
end
St = 0.34;
%Bondaries lock-in
LowerIL = 0.3/St;
UpperIL = 0.65/St;
LowerCF = 0.8/St;
UpperCF = 1.6/St;

%Reduced velocity
for i = 1:length(eigen)
    for j = 1:length(D)
        U_R(i,j) = u(j)/(eigen(i)*D(j));
    end
end

%Mode shapes
n = [1 3 5 7 9 11];
for i = 1:length(eigen)
    sfun1(i) = 0;
    sfun2(i) = 0;
    for j = 1:L-1
        mode(i,j) = sin((n(i)*pi/2)*(j/L))/sin(n(i)*pi/2);
        sfun1(i) = sfun1(i)+mode(i,j).^2;
        sfun2(i) = sfun2(i)+mode(i,j).^4;
    end
end

ymax = max(mode,[],2);

%Calculating mode shape parameter
for i = 1:length(eigen)
    gamma(i) = ymax(i)*sqrt(sfun1(i)/sfun2(i));
end

%Cross-flow amplitude
for i = 1:length(eigen)
    A_cf(i) = 0.31*gamma(i)*D_mean/sqrt(0.062+0.077*K_s(i)^2);
end








