%STRUCTURAL DAMPING
clear all;

%Import frequencies from first m modes
filename = 'eigen.xlsx';
eigen = xlsread(filename,'A:A');
omega = 2*pi*eigen;

m = length(eigen)/2.5;
n = length(eigen);

%Select damping ratios for first and m'th mode
zeta_1 = 0.05;
zeta_m = 0.10;

%Linear interpolation
for i = 1:n
    zeta_lin(i) = (((zeta_m-zeta_1)/(omega(m)-omega(1)))*...
        (omega(i)-omega(1)))+zeta_1;
end

%Linear interpolation of mode 1 < i < m
for i = 1:m
    zeta(i) = (((zeta_m-zeta_1)/(omega(m)-omega(1)))*...
        (omega(i)-omega(1)))+zeta_1;
end

%Extrapolation of values greater than m
for i = m+1:25
    zeta(i) = (((zeta_m-zeta_1)/(omega(m)-omega(1)))*...
        (omega(i)-omega(m)))+zeta_1;
end

%Obtaining beta value based on first data set
beta = ((2*zeta_1*omega(1))-(2*zeta_m*omega(m)))/...
    (omega(1)^2-omega(m)^2);

%Back-subsituting beta and obtaining alpha value
alpha = (2*zeta_1*omega(1))-(beta*omega(1)^2);

%Calculating beta value based on second data set
beta2 = ((2*zeta_1*omega(1))-(2*zeta(n)*omega(n)))/...
    (omega(1)^2-omega(n)^2);

%Alpha value based on second data set
alpha2 = (2*zeta_1*omega(1))-(beta2*omega(1)^2);

%Alpha and beta based on average values of the two first data sets
zeta_avg = (zeta_m+zeta(n))/2;
omega_avg = (omega(m)+omega(n))/2;

beta_avg = ((2*zeta_1*omega(1))-(2*zeta(n)*omega_avg))/...
    (omega(1)^2-omega_avg^2);
alpha_avg = (2*zeta_1*omega(1))-(beta_avg*omega(1)^2);

%Damping ratio for the 3 different sets of alpha and beta
for i = 1:n
    lambda1(i) = 0.5*((alpha/omega(i))+beta*omega(i));
    lambda2(i) = 0.5*((alpha2/omega(i))+beta2*omega(i));
    lambda_avg(i) = 0.5*((alpha_avg/omega(i))+beta_avg*omega(i));
end

plot(omega,zeta_lin,omega,lambda1,omega,lambda2,omega,lambda_avg)
xlabel('omega [rad/s]')
ylabel('lambda [-]')
legend('Linear interpolation','First 10 modes','Full range',...
    'Average values','Location','NorthWest')

%Calculating deviations
dev1 = 0;
dev2 = 0;
dev_avg = 0;
for i = 1:n
    dev1 = dev1 + abs(zeta_lin(i)-lambda1(i));
    dev2 = dev2 + abs(zeta_lin(i)-lambda2(i));
    dev_avg = dev_avg + abs(zeta_lin(i)-lambda_avg(i));
end

%Determinate damping approximation closest to the linear interpolation
if dev1 < dev2 && dev1 < dev_avg
    beta_a = beta;
    alpha_a = alpha;
elseif dev2 < dev_avg
    beta_a = beta2;
    alpha_a = alpha2;
else
    beta_a = beta_avg;
    alpha_a = alpha_avg;
end

%Write alpha and beta values
values = [alpha_a,beta_a];
writefile = 'damp.xlsx';
xlswrite(writefile,values);
